@@ -1086,8 +1086,8 @@ WW[̃t@C /Perl/site/lib/Sjis ɃRs[ 'use utf8;'
     perl5.006 ܂ perl5.00800 ̏ꍇŕR[h(0x5C)ŏIfBNg
     w肵Ďsɂ jacode.pl CuKvłB
 
-    perl5.008001ȍ~, perl5.010, perl5.012, perl5.014 ɂĕR[h(0x5C)
-    IfBNgw肵ĎsƂAWin32 W[
+    perl5.008001ȍ~, perl5.010, perl5.012, perl5.014, perl5.016 ɂĕR[h
+    (0x5C)ŏIfBNgw肵ĎsƂAWin32 W[
     Win32::GetShortPathName() ɂĒZO擾łꍇ chdir() 
     ܂BAchdir() ̃JgfBNg
     Win32::GetShortPathName() ɂĎ擾ZOɂȂ܂B
@@ -1127,9 +1127,9 @@ WW[̃t@C /Perl/site/lib/Sjis ɃRs[ 'use utf8;'
 
     Oq̂ƂAGXP[v̐K\ɂ̓}`oCgAJ[Ô
     ߂̋Lq @{Esjis::anchor} ǉ܂A̒Ɋ܂܂ \G ̐
-    ܂Bperl5.006, perl5.008, perl5.010, perl5.012, perl5.014 Ŏs
-    AΏە32,767oCg𒴂ʒuł̃}b`ׂƂŃ}b`
-    BȂA̍ۂɃG[xo͂܂B
+    ܂Bperl5.006, perl5.008, perl5.010, perl5.012, perl5.014, perl5.016 
+    sꍇAΏە32,767oCg𒴂ʒuł̃}b`ׂƂ
+    }b`܂BȂA̍ۂɃG[xo͂܂B
 
     QlN
     Bug #89792
@@ -1947,6 +1947,13 @@ vO~O񋟂܂B
  ISBN978-4-87311-427-9
  http://www.oreilly.co.jp/books/9784873114279/
 
+ ߂ĂPerl 6
+ Randal L. Schwartz, brian d foy, Tom Phoenix , ߓ Ð 
+ 2012N07 s
+ 488y[W
+ ISBN978-4-87311-567-2
+ http://www.oreilly.co.jp/books/9784873115672/
+
  Perl\[XLbg - UNIX
  Futato, Irving, Jepson, Patwardhan, Siever , CG[[x R{ _ 
  ISBN4-900900-65-6
